==> pycaption-2.0.dev3.tar.gz: pycaption-2.0.dev3/tests/conftest.py <==
from tests.fixtures.dfxp import (  # noqa: F401
    sample_dfxp, sample_dfxp_with_inline_style, sample_dfxp_with_defined_style,
    sample_dfxp_with_inherited_style, sample_dfxp_without_region_and_style,
    sample_dfxp_with_positioning, sample_dfxp_with_relativized_positioning,
    sample_dfxp_empty, sample_dfxp_syntax_error,
    sample_dfxp_from_sami_with_positioning,
    sample_dfxp_long_cue, sample_dfxp_long_cue_fit_to_screen,
    sample_dfxp_from_sami_with_margins, sample_dfxp_from_sami_with_lang_margins,
    sample_dfxp_from_sami_with_span, sample_dfxp_from_sami_with_bad_span_align,
    sample_dfxp_invalid_but_supported_positioning_input,
    sample_dfxp_invalid_but_supported_positioning_output,
    sample_dfxp_multiple_regions_input, sample_dfxp_multiple_regions_output,
    sample_dfxp_to_render_with_only_default_positioning_input,
    sample_dfxp_output, sample_dfxp_style_tag_with_no_xml_id_input,
    sample_dfxp_style_tag_with_no_xml_id_output, sample_dfxp_from_scc_output,
    sample_dfxp_with_properly_closing_spans_output,
    sample_dfxp_for_legacy_writer_input, sample_dfxp_for_legacy_writer_output,
    sample_dfxp_with_templated_style, sample_dfxp_with_escaped_apostrophe,
    sample_dfxp_with_alternative_timing_formats, sample_dfxp_empty_paragraph,
    sample_dfxp_incorrect_time_format, sample_dfxp_with_frame_timing,
    sample_dfxp_empty_cue, sample_dfxp_empty_cue_output,
    sample_dfxp_invalid_positioning_value_template,
    sample_dfxp_multiple_captions_with_the_same_timing,
    sample_dfxp_with_ampersand_character, sample_dfxp_with_nested_spans,
    dfxp_style_region_align_conflict, dfxp_with_concurrent_captions,
)
from tests.fixtures.microdvd import (  # noqa: F401
    sample_microdvd, sample_microdvd_2,
    sample_microdvd_invalid_format, missing_fps_sample_microdvd,
    sample_microdvd_empty, sample_microdvd_empty_cue_output,
)
from tests.fixtures.sami import (  # noqa: F401
    sample_sami, sample_sami_with_style_tags,
    sample_sami_with_css_inline_style, sample_sami_with_css_id_style,
    sample_sami_empty, sample_sami_syntax_error,
    sample_sami_double_br, sample_sami_partial_margins,
    sample_sami_partial_margins_relativized, sample_sami_lang_margin,
    sample_sami_with_span, sample_sami_with_bad_span_align,
    sample_sami_with_bad_div_align, sample_sami_with_p_align,
    sample_sami_with_p_and_span_align, sample_sami_with_multiple_span_aligns,
    sample_sami_no_lang, sample_sami_with_lang, sample_sami_with_multi_lang,
    sample_sami_with_multiple_p, sample_sami_empty_cue_output,
    sample_sami_with_invalid_inline_style,
    sample_sami_including_hexadecimal_charref,
    sample_sami_including_decimal_charref,
    sample_sami_including_html5_entityref, sample_sami_with_unclosed_tag,
    sample_sami_with_inline_lang, sample_sami_from_dfxp_with_nested_spans,
    sample_sami_with_separate_multi_lang,
)
from tests.fixtures.scc import (  # noqa: F401
    sample_scc_created_dfxp_with_wrongly_closing_spans,
    scc_that_generates_webvtt_with_proper_newlines,
    sample_scc_produces_captions_with_start_and_end_time_the_same,
    sample_scc_pop_on, sample_scc_multiple_positioning, sample_scc_with_italics,
    sample_scc_empty, sample_scc_roll_up_ru2,
    sample_scc_produces_bad_last_end_time, sample_no_positioning_at_all_scc,
    sample_scc_no_explicit_end_to_last_caption, sample_scc_flashing_captions,
    sample_scc_eoc_first_command, sample_scc_with_extended_characters,
    sample_scc_with_ampersand_character, sample_scc_multiple_formats,
    sample_scc_repeated_tab_offset, sample_scc_tab_offset,
    sample_scc_with_unknown_commands
)
from tests.fixtures.srt import (  # noqa: F401
    sample_srt, sample_srt_ascii, sample_srt_numeric, sample_srt_empty,
    sample_srt_blank_lines, sample_srt_trailing_blanks,
    samples_srt_same_time, sample_srt_empty_cue_output,
    sample_srt_timestamps_without_microseconds,
)
from tests.fixtures.translated_scc import (  # noqa: F401
    sample_translated_scc_custom_brackets, sample_translated_scc_success,
    sample_translated_scc_commands_not_found, sample_translated_scc_no_brackets
)
from tests.fixtures.webvtt import (  # noqa: F401
    sample_webvtt, sample_webvtt_from_dfxp, sample_webvtt_from_sami,
    sample_webvtt_from_sami_with_style, sample_webvtt_from_sami_with_id_style,
    sample_webvtt_from_dfxp_with_style,
    sample_webvtt_from_dfxp_with_positioning,
    sample_webvtt_from_dfxp_with_positioning_and_style,
    sample_webvtt_from_srt, sample_webvtt_from_webvtt,
    sample_webvtt_2, sample_webvtt_empty, sample_webvtt_double_br,
    sample_webvtt_output_long_cue, webvtt_from_dfxp_with_conflicting_align,
    sample_webvtt_with_cue_settings,
    sample_webvtt_from_scc_properly_writes_newlines_output,
    sample_webvtt_last_cue_zero_start, sample_webvtt_empty_cue,
    sample_webvtt_multi_lang_en, sample_webvtt_multi_lang_de,
    sample_webvtt_empty_cue_output, sample_webvtt_timestamps
)

==> pycaption-2.2.20.tar.gz: pycaption-2.2.20/tests/conftest.py <==
from tests.fixtures.dfxp import (  # noqa: F401
    sample_dfxp, sample_dfxp_with_inline_style, sample_dfxp_with_defined_style,
    sample_dfxp_with_inherited_style, sample_dfxp_without_region_and_style,
    sample_dfxp_with_positioning, sample_dfxp_with_relativized_positioning,
    sample_dfxp_empty, sample_dfxp_syntax_error,
    sample_dfxp_from_sami_with_positioning,
    sample_dfxp_long_cue, sample_dfxp_long_cue_fit_to_screen,
    sample_dfxp_from_sami_with_margins, sample_dfxp_from_sami_with_lang_margins,
    sample_dfxp_from_sami_with_span, sample_dfxp_from_sami_with_bad_span_align,
    sample_dfxp_invalid_but_supported_positioning_input,
    sample_dfxp_invalid_but_supported_positioning_output,
    sample_dfxp_multiple_regions_input, sample_dfxp_multiple_regions_output,
    sample_dfxp_to_render_with_only_default_positioning_input,
    sample_dfxp_output, sample_dfxp_style_tag_with_no_xml_id_input,
    sample_dfxp_style_tag_with_no_xml_id_output, sample_dfxp_from_scc_output,
    sample_dfxp_with_properly_closing_spans_output,
    sample_dfxp_for_legacy_writer_input, sample_dfxp_for_legacy_writer_output,
    sample_dfxp_with_templated_style, sample_dfxp_with_escaped_apostrophe,
    sample_dfxp_with_alternative_timing_formats, sample_dfxp_empty_paragraph,
    sample_dfxp_only_spaces_paragraph, sample_dfxp_incorrect_time_format,
    sample_dfxp_missing_begin, sample_dfxp_missing_end_and_dur,
    sample_dfxp_with_frame_timing, sample_dfxp_empty_cue,
    sample_dfxp_empty_cue_output, sample_dfxp_default_styling_p_tags,
    sample_dfxp_invalid_positioning_value_template,
    sample_dfxp_multiple_captions_with_the_same_timing,
    sample_dfxp_with_ampersand_character, sample_dfxp_with_nested_spans,
    dfxp_style_region_align_conflict, dfxp_with_concurrent_captions,
)
from tests.fixtures.microdvd import (  # noqa: F401
    sample_microdvd, sample_microdvd_2,
    sample_microdvd_invalid_format, missing_fps_sample_microdvd,
    sample_microdvd_empty, sample_microdvd_empty_cue_output,
)
from tests.fixtures.sami import (  # noqa: F401
    sample_sami, sample_sami_with_style_tags,
    sample_sami_with_css_inline_style, sample_sami_with_css_id_style,
    sample_sami_empty, sample_sami_syntax_error,
    sample_sami_double_br, sample_sami_partial_margins,
    sample_sami_partial_margins_relativized, sample_sami_lang_margin,
    sample_sami_with_span, sample_sami_with_bad_span_align,
    sample_sami_with_bad_div_align, sample_sami_with_p_align,
    sample_sami_with_p_and_span_align, sample_sami_with_multiple_span_aligns,
    sample_sami_no_lang, sample_sami_with_lang, sample_sami_with_multi_lang,
    sample_sami_with_multiple_p, sample_sami_empty_cue_output,
    sample_sami_with_invalid_inline_style,
    sample_sami_including_hexadecimal_charref,
    sample_sami_including_decimal_charref,
    sample_sami_including_html5_entityref, sample_sami_with_unclosed_tag,
    sample_sami_with_inline_lang, sample_sami_from_dfxp_with_nested_spans,
    sample_sami_with_separate_multi_lang, sample_sami_missing_start
)
from tests.fixtures.scc import (  # noqa: F401
    sample_scc_created_dfxp_with_wrongly_closing_spans,
    scc_that_generates_webvtt_with_proper_newlines,
    sample_scc_produces_captions_with_start_and_end_time_the_same,
    sample_scc_pop_on, sample_scc_multiple_positioning, sample_scc_with_italics,
    sample_scc_empty, sample_scc_roll_up_ru2, sample_scc_roll_up_ru3,
    sample_no_positioning_at_all_scc, sample_scc_with_line_too_long,
    sample_scc_no_explicit_end_to_last_caption, sample_scc_flashing_cue,
    sample_scc_eoc_first_command, sample_scc_with_extended_characters,
    sample_scc_with_ampersand_character, sample_scc_multiple_formats,
    sample_scc_duplicate_tab_offset, sample_scc_duplicate_special_characters,
    sample_scc_tab_offset, sample_scc_with_unknown_commands,
    sample_scc_special_and_extended_characters, sample_scc_mid_row_before_text_pop,
    sample_scc_mid_row_before_text_roll, sample_scc_mid_row_before_text_paint,
    sample_scc_mid_row_following_text_no_text_before_italics_off_pop,
    sample_scc_mid_row_following_text_no_text_before_italics_off_roll,
    sample_scc_mid_row_following_text_no_text_before_italics_off_paint,
    sample_scc_mid_row_following_text_no_text_before_italics_on_pop,
    sample_scc_mid_row_following_text_no_text_before_italics_on_roll,
    sample_scc_mid_row_following_text_no_text_before_italics_on_paint,
    sample_scc_mid_row_with_space_before_pop,
    sample_scc_mid_row_with_space_before_roll,
    sample_scc_mid_row_with_space_before_paint,
    sample_scc_with_spaces_at_eol_pop,
    sample_scc_with_spaces_at_eol_roll,
    sample_scc_with_spaces_at_eol_paint,
)
from tests.fixtures.srt import (  # noqa: F401
    sample_srt, sample_srt_ascii, sample_srt_numeric, sample_srt_empty,
    sample_srt_blank_lines, sample_srt_trailing_blanks,
    samples_srt_same_time, sample_srt_empty_cue_output,
    sample_srt_timestamps_without_microseconds,
)
from tests.fixtures.translated_scc import (  # noqa: F401
    sample_translated_scc_custom_brackets, sample_translated_scc_success,
    sample_translated_scc_commands_not_found, sample_translated_scc_no_brackets,
    sample_translated_scc_special_and_extended_characters
)
from tests.fixtures.webvtt import (  # noqa: F401
    sample_webvtt, sample_webvtt_from_dfxp, sample_webvtt_from_sami,
    sample_webvtt_from_sami_with_style, sample_webvtt_from_sami_with_id_style,
    sample_webvtt_from_dfxp_with_style,
    sample_webvtt_keeps_positioning,
    sample_webvtt_from_dfxp_with_positioning_and_style,
    sample_webvtt_from_srt, sample_webvtt_from_webvtt,
    sample_webvtt_2, sample_webvtt_empty, sample_webvtt_double_br,
    sample_webvtt_output_long_cue, webvtt_from_dfxp_with_conflicting_align,
    sample_webvtt_with_cue_settings,
    sample_webvtt_from_scc_properly_writes_newlines_output,
    sample_webvtt_last_cue_zero_start, sample_webvtt_empty_cue,
    sample_webvtt_multi_lang_en, sample_webvtt_multi_lang_de,
    sample_webvtt_empty_cue_output, sample_webvtt_timestamps
)
